import math
import argparse

from tkinter import *

def calculate_num_of_solar_panels_at_angle(length_roof: float, width_roof: float, length_solar_panel : float, width_solar_panel : float, angle_in_degrees : float, length_unusable_area_1 : float, width_unusable_area_1 : float, length_unusable_area_2 : float = 0, width_unusable_area_2 : float = 0):
    
    
    angle_radian_1 = math.radians(180 - 90 - angle_in_degrees)
    angle_radian_2 = math.radians(angle_in_degrees)
    c_1 = length_solar_panel
    c_2 = width_solar_panel


    
    b_1 = c_1 * math.sin(angle_radian_1)
    b_2 = c_2 * math.sin(angle_radian_2)

    a_1 = c_1 * math.cos(angle_radian_1)
    a_2 = c_2 * math.cos(angle_radian_2)


    A = a_1 + a_2
    B = b_1 + b_2


    solar_panel_area = A * B
    print("Total area (m^2) of on solar panel: ", solar_panel_area)

    C = length_roof * width_roof
    num_of_solar_panels_on_roof = C / (solar_panel_area)
    
    unusable_area_1 = length_unusable_area_1 * width_unusable_area_1
    num_of_solar_panels_in_unusable_area_1 = unusable_area_1 / solar_panel_area

    num_of_solar_panels_in_unusable_area_2 = 0
    if length_unusable_area_2 != None and width_unusable_area_2 != None and length_unusable_area_2 != 0 and width_unusable_area_2 != 0:
        unusable_area_2 = length_unusable_area_2* width_unusable_area_2
        num_of_solar_panels_in_unusable_area_2 = unusable_area_2 / solar_panel_area

    total_num_of_solar_panels = num_of_solar_panels_on_roof - num_of_solar_panels_in_unusable_area_1
    if num_of_solar_panels_in_unusable_area_2 != 0:
        total_num_of_solar_panels = total_num_of_solar_panels - num_of_solar_panels_in_unusable_area_2
    
    print("Number of solar panels that fit on roof at an angle: ", total_num_of_solar_panels)
    return total_num_of_solar_panels



def calculate_num_of_solar_panels(length_roof: float, width_roof: float, length_solar_panel : float, width_solar_panel : float, length_unusable_area_1 : float, width_unusable_area_1 : float, length_unusable_area_2 : float = 0, width_unusable_area_2 : float = 0):

    tot_roof_area = length_roof * width_roof
    solar_panel_area = length_solar_panel * width_solar_panel

    num_of_solar_panels_total_area = tot_roof_area / solar_panel_area

    unusable_area = length_unusable_area_1 * width_unusable_area_1
    num_of_solar_panels_unusable_area = unusable_area / solar_panel_area

    num_of_solar_panels_unusable_area_2 = 0
    if length_unusable_area_2 != None and width_unusable_area_2 != None and length_unusable_area_2 != 0 and width_unusable_area_2 != 0:
        unusable_area_2 = length_unusable_area_2 * width_unusable_area_2
        num_of_solar_panels_unusable_area_2 = unusable_area_2 / solar_panel_area

    tot_num_of_solar_panels = num_of_solar_panels_total_area - num_of_solar_panels_unusable_area
    if num_of_solar_panels_unusable_area_2 != 0:
        tot_num_of_solar_panels = tot_num_of_solar_panels - num_of_solar_panels_unusable_area_2

    print("Number of solar panels that fit on roof (not at an angle): ", tot_num_of_solar_panels)
    return tot_num_of_solar_panels


def calculate_and_display():
    try:
        lengde_tak = float(lengde_tak_entry.get())
        bredde_tak = float(bredde_tak_entry.get())
        lengde_solcelle = float(lengde_solcelle_entry.get())
        bredde_solcelle = float(bredde_solcelle_entry.get())
        vinkel = float(vinkel_entry.get())
        u1_lengde = float(u1_lengde_entry.get())
        u1_bredde = float(u1_bredde_entry.get())
        
        u2_lengde = u2_lengde_entry.get()
        if u2_lengde != None and u2_lengde != "":
            u2_lengde = float(u2_lengde_entry.get())
        else:
            u2_lengde = None
        
        u2_bredde = u2_bredde_entry.get()
        if u2_bredde != None and u2_bredde != "":
            u2_bredde = float(u2_bredde_entry.get())
        else:
            u2_bredde = None

        print(f"Taklengde: {lengde_tak}")
        print(f"Takbredde: {bredde_tak}")
        print(f"Solcellelengde: {lengde_solcelle}")
        print(f"Solcellebredde: {bredde_solcelle}")
        print(f"Vinkel: {vinkel}")
        print(f"Ubrukelig område 1 lengde: {u1_lengde}")
        print(f"Ubrukelig område 1 bredde: {u1_bredde}")
        print(f"Ubrukelig område 2 lengde: {u2_lengde}")
        print(f"Ubrukelig område 2 bredde: {u2_bredde}")
        num_of_solar_panels_at_angle = calculate_num_of_solar_panels_at_angle(lengde_tak, bredde_tak, lengde_solcelle, bredde_solcelle, vinkel, u1_lengde, u1_bredde, u2_lengde, u2_bredde)
        num_of_solar_panels_not_at_angle = calculate_num_of_solar_panels(lengde_tak, bredde_tak, lengde_solcelle, bredde_solcelle, u1_lengde, u1_bredde, u2_lengde, u2_bredde)

        answer_label.config(text=f"Number of solar panels that fit on roof at an angle: {num_of_solar_panels_at_angle}")
        answer_label_2.config(text=f"Number of solar panels that fit on roof (not at an angle): {num_of_solar_panels_not_at_angle}")
    except ValueError:
        answer_label.config(text="Feil i input. Vennligst bruk tall-verdier.")
        answer_label_2.config(text="Feil i input. Vennligst bruk tall-verdier.")




# Create the main window
window = Tk()
window.title("Solcellepanelberegning")

# Create labels and entry fields
lengde_tak_label = Label(window, text="Taklengde (m):")
lengde_tak_label.pack()

lengde_tak_entry = Entry(window)
lengde_tak_entry.pack()

bredde_tak_label = Label(window, text="Takbredde (m):")
bredde_tak_label.pack()

bredde_tak_entry = Entry(window)
bredde_tak_entry.pack()

lengde_solcelle_label = Label(window, text="Solcellelengde (m):")
lengde_solcelle_label.pack()

lengde_solcelle_entry = Entry(window)
lengde_solcelle_entry.pack()

bredde_solcelle_label = Label(window, text="Solcellebredde (m):")
bredde_solcelle_label.pack()

bredde_solcelle_entry = Entry(window)
bredde_solcelle_entry.pack()

vinkel_label = Label(window, text="Vinkel (grader):")
vinkel_label.pack()

vinkel_entry = Entry(window)
vinkel_entry.pack()

u1_lengde_label = Label(window, text="Ubrukelig område 1 lengde (m):")
u1_lengde_label.pack()

u1_lengde_entry = Entry(window)
u1_lengde_entry.pack()

u1_bredde_label = Label(window, text="Ubrukelig område 1 bredde (m):")
u1_bredde_label.pack()

u1_bredde_entry = Entry(window)
u1_bredde_entry.pack()

u2_lengde_label = Label(window, text="Ubrukelig område 2 lengde (m):")
u2_lengde_label.pack()

u2_lengde_entry = Entry(window)
u2_lengde_entry.pack()

u2_bredde_label = Label(window, text="Ubrukelig område 2 bredde (m):")
u2_bredde_label.pack()

u2_bredde_entry = Entry(window)
u2_bredde_entry.pack()

# Create a button to trigger calculation
submit_button = Button(window, text="Beregn", command=calculate_and_display)
submit_button.pack()

# Label to display the answer
answer_label = Label(window, text="Beregnet verdi:")
answer_label.pack()

answer_label_2 = Label(window, text="Beregnet verdi:")
answer_label_2.pack()

# Run the main event loop
window.mainloop()

#parser = argparse.ArgumentParser()
#parser.add_argument("-lengde_tak", help="tak lengde", type=float)
#parser.add_argument("-bredde_tak", help="tak bredde", type=float)
#parser.add_argument("-lengde_solcelle",   help="solcelle lengde", type=float)
#parser.add_argument("-bredde_solcelle", help="solcelle bredde", type=float)
#parser.add_argument("-vinkel", help="vinkel i grader", type=float)
#parser.add_argument("-u1_lengde", help="Lengde på ubrukelig område 1", type=float)
#parser.add_argument("-u1_bredde", help="Bredde på ubrukelig område 1", type=float)
#parser.add_argument("-u2_lengde", help="Lengde på ubrukelig område 2", type=float)
#parser.add_argument("-u2_bredde", help="Bredde på ubrukelig område 2", type=float)

#args = parser.parse_args()

#calculate_num_of_solar_panels_at_angle(args.lengde_tak, args.bredde_tak, args.lengde_solcelle, args.bredde_solcelle, args.vinkel, args.u1_lengde, args.u1_bredde, args.u2_lengde, args.u2_bredde)
#calculate_num_of_solar_panels(args.lengde_tak, args.bredde_tak, args.lengde_solcelle, args.bredde_solcelle, args.u1_lengde, args.u1_bredde, args.u2_lengde, args.u2_bredde)

