import matplotlib.pyplot as plt
import numpy as np
import pandas as pd

def create_grouped_bar_chart(filenames, output_filename = 'total_system_bar_chart.pdf'):

    # Reading CSV files as dataframes
    data_frames = []
    for filename in filenames:
        df = pd.read_csv(filename)
        data_frames.append(df)

    # Summing AC and load of each building
    sum_of_ac = None
    sum_of_load = None
    for i in range(0,len(data_frames)):
        df = data_frames[i]
        if i == 0:
             sum_of_ac = df['AC energy (year 1) | (kWh/mo)']
             sum_of_load = df['Electricity load | (kWh/mo)']
        else:
            sum_of_ac = sum_of_ac + df['AC energy (year 1) | (kWh/mo)']
            sum_of_load = sum_of_load + df['Electricity load | (kWh/mo)']
            
    
    # Creating dataframe containing months, total AC and total load
    ac_and_load_data = {'month': ['Jan', 'Feb', 'Mar', 'Apr', 'Mai', 'Jun', 'Jul', 'Aug', 'Sep', 'Okt', 'Nov', 'Des'],
        'Total last': sum_of_load, 'Total AC Energi': sum_of_ac}
    df_ac_and_load = pd.DataFrame(ac_and_load_data)
    print(df_ac_and_load)


    # Plotting grouped bar chart 
    df_ac_and_load.plot(kind = 'bar', x='month')
    plt.xlabel("Måned")
    plt.ylabel("Energi [kWh]")
    plt.grid(color = 'grey', linestyle = '--', linewidth = 0.5)
    plt.savefig(output_filename, dpi=300, format='pdf', bbox_inches='tight')


def create_bar_chart_discounted_payback(filenames, output_filename = 'discounted_payback_bar_chart.pdf', years = 25):
    
    # Reading CSV files as dataframes
    data_frames = []
    for filename in filenames:
        df = pd.read_csv(filename)
        data_frames.append(df)

    # Summing discounted payback of each building
    sum_of_discounted_payback = None
    for i in range(0,len(data_frames)):
        df = data_frames[i]
        if i == 0:
             sum_of_discounted_payback = df['Cumulative discounted payback | ($)']
        else:
            sum_of_discounted_payback = sum_of_discounted_payback + df['Cumulative discounted payback | ($)']
    
    # Creating dataframe containing months, total AC and total load
    periods = [i for i in range(0, years + 1)]
    discounted_payback_data = {'period': periods, 'Diskontert tilbakebetaling': sum_of_discounted_payback}
    df_discounted_payback = pd.DataFrame(discounted_payback_data)
    print(df_discounted_payback)

    # Plotting grouped bar chart 
    df_discounted_payback.plot(kind = 'bar', x='period')
    plt.xlabel("År")
    plt.ylabel("Kostnad ($)")
    plt.grid(color = 'grey', linestyle = '--', linewidth = 0.5)
    plt.savefig(output_filename, dpi=300, format='pdf', bbox_inches='tight')


files_375 = ['CSVFiler/375W/gneis_prod_375.csv', 'CSVFiler/375W/ametyst_prod_375.csv', 'CSVFiler/375W/kobolt_prod_375.csv', 'CSVFiler/375W/beryll_prod_375.csv']
files_585 = ['CSVFiler/585W/gneis_prod_585.csv', 'CSVFiler/585W/ametyst_prod_585.csv', 'CSVFiler/585W/kobolt_prod_585.csv', 'CSVFiler/585W/beryll_prod_585.csv']

output_file_375 = 'output_prod_375W.pdf'
output_file_585 = 'output_prod_585W.pdf'

create_grouped_bar_chart(files_375, output_file_375)
create_grouped_bar_chart(files_585, output_file_585)

files_375_discpb = ['CSVFiler/375W/gneis_discpb_375.csv', 'CSVFiler/375W/ametyst_discpb_375.csv', 'CSVFiler/375W/kobolt_discpb_375.csv', 'CSVFiler/375W/beryll_discpb_375.csv']
files_585_discpb = ['CSVFiler/585W/gneis_discpb_585.csv', 'CSVFiler/585W/ametyst_discpb_585.csv', 'CSVFiler/585W/kobolt_discpb_585.csv', 'CSVFiler/585W/beryll_discpb_585.csv']

output_file_375_discpb = 'output_discpb_375W.pdf'
output_file_585_discpb = 'output_discpb_585W.pdf'
create_bar_chart_discounted_payback(files_375_discpb, output_file_375_discpb, 25)
create_bar_chart_discounted_payback(files_585_discpb, output_file_585_discpb, 30)